import { DefaultLogger } from './logger';
export class LoggableExtension {
    /**
     Turn on Auth0.swift debug logging of HTTP requests and OAuth2 flow (iOS only) with a custom logger.

     - parameter logger: logger used to print log statements
     - note: By default all logging is **disabled**
     - important: Logging should be turned on/off **before** making request to Auth0 for the flag to take effect.
     */
    static using(loggable, logger) {
        loggable.logger = logger;
        return loggable;
    }
    /**
     Turn on/off Auth0.swift debug logging of HTTP requests and OAuth2 flow (iOS only).

     - parameter enabled: optional flag to turn on/off logging
     - note: By default all logging is **disabled**
     - important: Logging should be turned on/off **before** making request to Auth0 for the flag to take effect.
     */
    static logging(loggable, enabled) {
        if (enabled) {
            loggable.logger = new DefaultLogger();
        }
        else {
            loggable.logger = undefined;
        }
        return loggable;
    }
}
//# sourceMappingURL=loggable.js.map